==> rest-assured-2.4.0-sources.jar: com/jayway/restassured/internal/filter/FilterContextImpl.java <==
package com.jayway.restassured.internal.filter;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class FilterContextImpl
  extends java.lang.Object  implements
    com.jayway.restassured.filter.FilterContext,    groovy.lang.GroovyObject {
public FilterContextImpl
(java.lang.String completePath, java.lang.String path, com.jayway.restassured.internal.http.Method method, java.lang.Object assertionClosure, java.util.List<com.jayway.restassured.filter.Filter> filterList) {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getAssertionClosure() { return null;}
public  void setAssertionClosure(java.lang.Object value) { }
public  java.lang.Object getProperties() { return null;}
public  void setProperties(java.lang.Object value) { }
public  com.jayway.restassured.response.Response next(com.jayway.restassured.specification.FilterableRequestSpecification request, com.jayway.restassured.specification.FilterableResponseSpecification response) { return (com.jayway.restassured.response.Response)null;}
public  java.lang.String getRequestPath() { return (java.lang.String)null;}
public  com.jayway.restassured.internal.http.Method getRequestMethod() { return (com.jayway.restassured.internal.http.Method)null;}
public  java.lang.String getCompleteRequestPath() { return (java.lang.String)null;}
public  com.jayway.restassured.response.Response send(com.jayway.restassured.specification.RequestSender requestSender) { return (com.jayway.restassured.response.Response)null;}
public  void setValue(java.lang.String name, java.lang.Object value) { }
public  boolean hasValue(java.lang.String name) { return false;}
public  java.lang.Object getValue(java.lang.String name) { return null;}
}

==> rest-assured-2.9.0-sources.jar: com/jayway/restassured/internal/filter/FilterContextImpl.java <==
package com.jayway.restassured.internal.filter;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class FilterContextImpl
  extends java.lang.Object  implements
    com.jayway.restassured.filter.FilterContext,    groovy.lang.GroovyObject {
public FilterContextImpl
(java.lang.String requestUri, java.lang.String fullOriginalPath, java.lang.String fullSubstitutedPath, java.lang.String internalRequestUri, java.lang.String userDefinedPath, java.lang.Object[] unnamedPathParams, com.jayway.restassured.http.Method method, java.lang.Object assertionClosure, java.util.Iterator<com.jayway.restassured.filter.Filter> filters, java.util.Map<java.lang.String, java.lang.Object> properties) {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getAssertionClosure() { return null;}
public  void setAssertionClosure(java.lang.Object value) { }
public  java.util.Map<java.lang.String, java.lang.Object> getProperties() { return (java.util.Map)null;}
public  void setProperties(java.util.Map<java.lang.String, java.lang.Object> value) { }
public  com.jayway.restassured.response.Response next(com.jayway.restassured.specification.FilterableRequestSpecification request, com.jayway.restassured.specification.FilterableResponseSpecification response) { return (com.jayway.restassured.response.Response)null;}
public  java.lang.String getRequestPath() { return (java.lang.String)null;}
public  java.lang.String getOriginalRequestPath() { return (java.lang.String)null;}
public  com.jayway.restassured.internal.http.Method getRequestMethod() { return (com.jayway.restassured.internal.http.Method)null;}
public  java.lang.String getRequestURI() { return (java.lang.String)null;}
@java.lang.SuppressWarnings(value="GroovyUnusedDeclaration") public  java.lang.String getInternalRequestURI() { return (java.lang.String)null;}
public  java.lang.String getCompleteRequestPath() { return (java.lang.String)null;}
public  com.jayway.restassured.response.Response send(com.jayway.restassured.specification.RequestSender requestSender) { return (com.jayway.restassured.response.Response)null;}
public  void setValue(java.lang.String name, java.lang.Object value) { }
public  boolean hasValue(java.lang.String name) { return false;}
public  java.lang.Object getValue(java.lang.String name) { return null;}
}
